pub struct PrivateKey { /* private fields */ }Expand description
PKCS#8 private key wrapper
Implementations
Sourceimpl PrivateKey
impl PrivateKey
Sourcepub fn from_der(data: &[u8]) -> Result<Self>
pub fn from_der(data: &[u8]) -> Result<Self>
Parses a PKCS#8 private key encoded in DER format and constructs a new instance of the struct.
Sourcepub fn as_der(&self) -> &[u8] ⓘ
pub fn as_der(&self) -> &[u8] ⓘ
Returns a reference to the private key data in PKCS#8 DER-encoded format.
Sourcepub fn oid(&self) -> ObjectIdentifier
pub fn oid(&self) -> ObjectIdentifier
Returns an ObjectIdentifier of the key algorithm.