PrivateKeyChain

Struct PrivateKeyChain 

pub struct PrivateKeyChain { /* private fields */ }
PrivateKeyChain represents a private key and a certificate chain

Implementations

Source

impl PrivateKeyChain

pub fn new<K, D, I>(key: K, local_key_id: D, chain: I) -> Self
where K: AsRef<[u8]>, D: AsRef<[u8]>, I: IntoIterator<Item = Certificate>,

Creates a new keychain with a given key data, key id and a list of certificates. The leaf (entity) certificate must be the first in the list, and the root certificate must be the last.

pub fn key(&self) -> &[u8]

Get private key data

pub fn chain(&self) -> &[Certificate]

Get a slice of certificates

pub fn local_key_id(&self) -> &[u8]

Get local key id