pub struct PrivateKeyChain { /* private fields */ }Expand description
PrivateKeyChain represents a private key and a certificate chain
Implementations
Sourceimpl PrivateKeyChain
impl PrivateKeyChain
Sourcepub fn new<K, D, I>(key: K, local_key_id: D, chain: I) -> Self
pub fn new<K, D, I>(key: K, local_key_id: D, chain: I) -> Self
Creates a new keychain with a given key data, key id and a list of certificates. The leaf (entity) certificate must be the first in the list, and the root certificate must be the last.
Sourcepub fn chain(&self) -> &[Certificate]
pub fn chain(&self) -> &[Certificate]
Get a slice of certificates
Sourcepub fn local_key_id(&self) -> &[u8] ⓘ
pub fn local_key_id(&self) -> &[u8] ⓘ
Get local key id